Package: sfsmisc
Title: Utilities from 'Seminar fuer Statistik' ETH Zurich
Version: 1.1-24
VersionNote: Last CRAN: 1.1-23 on 2025-11-20; CRAN: 1.1-22 on
        2025-08-30; 1.1-21 on 2025-07-25
Date: 2026-05-14
Authors@R: c(person("Martin","Maechler", role=c("aut","cre"), email="maechler@stat.math.ethz.ch",
	                                 comment = c(ORCID = "0000-0002-8685-9910"))
	   , person("Werner", "Stahel", role = "ctb",
	   	   comment = "Functions: compresid2way(), f.robftest(), last(), p.scales(), p.dnorm()")
	   , person("Andreas", "Ruckstuhl", role = "ctb",
	   	   comment = "Functions: p.arrows(), p.profileTraces(), p.res.2x()")
	   , person("Christian", "Keller", role = "ctb",
	   	   comment = "Functions: histBxp(), p.tachoPlot()")
	   , person("Kjetil", "Halvorsen", role = "ctb",
	   	   comment = "Functions: KSd(), ecdf.ksCI()")
	   , person("Alain", "Hauser", role = "ctb",
	   	   comment = "Functions: cairoSwd(), is.whole(), toLatex.numeric()*")
	   , person("Christoph", "Buser", role = "ctb",
	   	   comment = "to function Duplicated()")
	   , person("Lorenz", "Gygax", role = "ctb",
	   	   comment = "to function p.res.2fact()")
	   , person("Bill", "Venables", role = "ctb",
	   	   comment = "Functions: empty.dimnames(), primes()")
	   , person("Tony", "Plate", role = "ctb", comment = "to inv.seq()")
	   # minor contributors:
	   , person("Isabelle", "Flückiger", role = "ctb")
	   , person("Marcel", "Wolbers", role = "ctb")
	   , person("Markus", "Keller", role = "ctb")
	   , person("Sandrine", "Dudoit", role = "ctb")
	   , person("Jane", "Fridlyand", role = "ctb")
	   , person("Greg", "Snow", role = "ctb", comment = "to loessDemo()")
	   , person("Henrik Aa.", "Nielsen", role = "ctb", comment = "to loessDemo()")
	   , person("Vincent", "Carey", role = "ctb")
	   , person("Ben", "Bolker", role = "ctb")
	   , person("Philippe", "Grosjean", role = "ctb")
	   , person("Frédéric", "Ibanez", role = "ctb")
	   , person("Caterina", "Savi", role = "ctb")
	   , person("Charles", "Geyer", role = "ctb")
	   , person("Jens", "Oehlschlägel", role = "ctb")
 )
Maintainer: Martin Maechler <maechler@stat.math.ethz.ch>
Description: Useful utilities ['goodies'] from Seminar fuer Statistik ETH Zurich,
   some of which were ported from S-plus in the 1990s.
 For graphics, have pretty (Log-scale) axes eaxis(), an enhanced Tukey-Anscombe
   plot, combining histogram and boxplot, 2d-residual plots, a 'tachoPlot()',
   pretty arrows, etc.
 For robustness, have a robust F test and robust range().
 For system support, notably on Linux, provides 'Sys.*()' functions with
   more access to system and CPU information.
 Finally, miscellaneous utilities such as simple efficient prime numbers,
   integer codes, Duplicated(), toLatex.numeric() and is.whole().
Depends: R (>= 3.3.0)
Imports: grDevices, utils, stats, tools
Suggests: datasets, tcltk, cluster, lattice, MASS, Matrix, nlme,
        lokern, Rmpfr, gmp
Enhances: mgcv, rpart, nor1mix, polycor, sm, tikzDevice, DescTools,
        e1071, Hmisc, pastecs, polynom, relevance, robustbase
EnhancesNote: 2nd line: packages mentioned in Rd xrefs
Encoding: UTF-8
ByteCompile: yes
License: GPL (>= 2)
URL: https://github.com/mmaechler/sfsmisc
BugReports: https://github.com/mmaechler/sfsmisc/issues
NeedsCompilation: no
Packaged: 2026-05-14 21:41:08 UTC; maechler
Author: Martin Maechler [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-8685-9910>),
  Werner Stahel [ctb] (Functions: compresid2way(), f.robftest(), last(),
    p.scales(), p.dnorm()),
  Andreas Ruckstuhl [ctb] (Functions: p.arrows(), p.profileTraces(),
    p.res.2x()),
  Christian Keller [ctb] (Functions: histBxp(), p.tachoPlot()),
  Kjetil Halvorsen [ctb] (Functions: KSd(), ecdf.ksCI()),
  Alain Hauser [ctb] (Functions: cairoSwd(), is.whole(),
    toLatex.numeric()*),
  Christoph Buser [ctb] (to function Duplicated()),
  Lorenz Gygax [ctb] (to function p.res.2fact()),
  Bill Venables [ctb] (Functions: empty.dimnames(), primes()),
  Tony Plate [ctb] (to inv.seq()),
  Isabelle Flückiger [ctb],
  Marcel Wolbers [ctb],
  Markus Keller [ctb],
  Sandrine Dudoit [ctb],
  Jane Fridlyand [ctb],
  Greg Snow [ctb] (to loessDemo()),
  Henrik Aa. Nielsen [ctb] (to loessDemo()),
  Vincent Carey [ctb],
  Ben Bolker [ctb],
  Philippe Grosjean [ctb],
  Frédéric Ibanez [ctb],
  Caterina Savi [ctb],
  Charles Geyer [ctb],
  Jens Oehlschlägel [ctb]
Repository: CRAN
Date/Publication: 2026-05-15 06:30:02 UTC
