importFrom("grDevices", boxplot.stats, cairo_pdf,
	   dev.cur, dev.off
         , grSoftVersion
         , n2mfrow, pdf, postscript
         , xy.coords)


importFrom("graphics", abline, arrows, axTicks, axis, axis.POSIXct,
	   boxplot, curve, frame, hist, lines, locator, matplot, mtext,
	   par, plot.new, points, polygon,
	   rug, segments, symbols, text, xyinch)

if(getRversion() < "4.0.0")
    importFrom("graphics", plot)


importFrom("stats",
	   IQR, approx, as.formula, as.ts, dchisq, dgamma, density.default,
	   dnorm, dummy.coef, ecdf, end, family, fitted, formula, getCall, is.ts,
	   lm, lowess, loess, loess.control,
	   mad, median, model.frame, na.exclude, na.omit, napredict,
	   pchisq, pf, plot.ts, predict, qchisq, qgamma, qnorm, qt, quantile,
	   resid, residuals, runif,
           setNames,
	   smooth.spline, spline, splinefun, start, stepfun, symnum,
	   terms, time, update.formula, var, window)

importFrom("utils", head, tail, toLatex, #<- S3 generics !
           help,
	   capture.output, count.fields, data, packageDescription, read.table,
	   sessionInfo, str)

importFrom("tools", Rcmd)



### Export almost all
##  ------
## New scheme (at first: for new things, only):
#  group exported objects  __by ./R/ (and maybe ./man/) source file__
export (
        ## ./R/prime-numbers-fn.R :
        primes, factorize,
	GCD, LCM,

	"AsciiToInt",
	"as.intBase", "bi2int",
    ## FIXME: currently needed from FrF2 (Ulrike Groemping):
        "as.integer.basedInt",
	"axTexpr",
	"repChar", "bl.string",
	"cairoSwd",
	"capture.and.write",
	"ccat",
	"chars8bit",
	"code2n",
	"col01scale",
	"colcenter",
        "compact01",
	"compresid2way",
	"cum.Vert.funkt",

	"C.Monatsname", "C.weekday", "C.Wochentag", "C.Wochentagkurz",

	"D1D2", "D1ss", "D1tr", "D2ss",
	"dDA",
	"diagDA",
	"diagX",
	"digitsBase",
	"Duplicated",
	"eaxis",
	"ecdf.ksCI",
	"ellipsePoints",
	"empty.dimnames",
	"errbar",
	"f.robftest",
    formatN,
    funEnv,
	"hatMat",
        "histBxp", # defunct: "hist.bxp"
    helppdf,
	"ichar",
	"integrate.xy",
	"inv.seq",
    isRshared,
	"is.whole",
	"iterate.lin.recursion",
	"KSd",
    list_,
	"last",
	"linesHyperb.lm",
	"list2mat",
    loessDemo,
	"lseq",
	"margin2table",
	"mat2tex",
    missingCh,
	"mpl",
	"mult.fig",
## FIXME: This is deprecated (but was never announced anyway...) :
        nearcor,
	"n.code",
	"n.plot",
	"nr.sign.chg",
	"paste.vec",

	"p.arrows",
	"p.datum",

	"p.dchisq", "p.dgamma", "p.dnorm",

	"p.hboxp",
	"plotDS",
        "pl.ds", ## <- deprecated
	"plotStep",
	"p.m",

        ## these should probably be deprecated for  pmax.int(), pmin.int():
	"pmax.sa", "pmin.sa",

	"polyn.eval",
	"posdefify",
	"p.pllines",
	"p.profileTraces",
	"p.res.2fact",
	"p.res.2x",
	"pretty10exp",

	## not the S3 methods:
	## "predict.dDA",
        ## "print.basedInt", "print.dDA", "print.margin2table",

    pkgDesc, pkgBuilt,

	"printTable2",
	"prt.DEBUG",

	"pdf.do", "pdf.end", "pdf.latex",
	"ps.do",  "ps.end",  "ps.latex",

	"p.scales",
        "p.tachoPlot",
	"p.ts",

	"quadrant",
	"QUnif",

        read.org.table,
    relErrV, relErr,
	"rot2", "rotn",
	"roundfixS",
	"rrange",
	"sHalton",
	"seqXtend",
    sessionInfoX,
    shortRversion,
	"signi",
        "sourceAttach",
	"strcodes",
	"str_data",
	"TA.plot",
	"tapplySimpl",
	"tkdensity",
	"u.boxplot.x",
	"u.date", "u.datumdecode", "u.Datumvonheute",
	"u.assign0", "u.get0",
	"u.log",
	"unif",
	"uniqueL",
	"u.sys",
	"vcat",
        "wrapFormula",
	"xy.grid", "xy.unique.x"
	)

export("Sys.ps.cmd") # now in general.. even though possibly nonfunctional in non-unix
if(tools:::.OStype() == "unix") { ## those are inside R/unix/

    export("Sys.ps", "Sys.sizes")

    if(identical(1L, grep("linux", R.version[["os"]]))) { ##--- Linux - only ---
	export("Sys.cpuinfo", "Sys.meminfo", "Sys.MIPS", "Sys.memGB")
    }

    export("pkgLibs")
}

S3method(predict, dDA)
S3method(print, dDA)
S3method(print, basedInt)
S3method(print, sessionInfoX)
S3method(as.integer, basedInt)

S3method(print, margin2table)

S3method(toLatex, numeric)

S3method(p.res.2x, default)
S3method(p.res.2x, formula)
